
# Table of Contents

1.  [naipyext](#org4b8b3b8)


<a id="org4b8b3b8"></a>

# naipyext

Nasy IPython Extensions.

Add

    c.InteractiveShellApp.extensions = [
        "autoreload",
        "naipyext.autotime",
        "naipyext.be",
        "naipyext.ns",
        "naxpyext.pt"
    ]

to ipython config file `$HOME/.ipython/profile_default/ipython_config.py`

